# AlgoInfinite

A collection of algorithms and data structures in Python.

## Installation

```bash
pip install algoinfinite

```
## Usage

```python
from algoinfinite import *
```

## Command Line Usage
```bash
madan-hello
```
